
Author: Yvonne Anderson


Contact: ee22ya@leeds.ac.uk 


Dataset created: 21/08/2023

Paper title: Minimal influence of future Arctic sea ice loss on North Atlantic jet stream morphology, Author: Yvonne Anderson

# Dataset information

CSV files contain arrays of daily jet feature data for all ensemble member winters for a given model.
Dimensions of the arrays are (number of ensemble members, 90 winter days).

## Filename structure
Filenames of CSV files can be interpreted as: timeperiod_jetfeature_model.csv

### Example filename structure
| Time period |Jet feature| Model| Example filename |
|----------|----------|----------|----------| 
| Present-day | Latitude | AWI-CM-1-1-MR|present-day_jet_latitude_AWI-CM-1-1-MR.csv |
| Future | Speed | HadGEM3-GC31-MM|future_jet_speed_HadGEM3-GC31-MM.csv |

## Jet feature description
Jet feature data are for the largest mass jet region found on each day of winter, where jet mass is the area weighted jet speed.

The jet features and corresponding units contained in the csv files are as follows:
| Jet feature | Units |
|----------|----------|
| Latitude | &deg; |
| Speed | ms<sup>-1</sup> |
| Mass | ms<sup>-1</sup> |
| Tilt | &deg; |
| Area | m<sup>2</sup> |

## Time periods
Time periods are present-day and future, which refer to simulations forced by present-day and future sea ice concentrations, from which the jet features have been extracted.

## Models
Models are AWI-CM-1-1-MR, CanESM5, FGOALS-f3-L, HadGEM3-GC31-MM, IPSL-CM6A-LR and MIROC6 from the Polar Amplification Model Intercomparison Project (PAMIP; https://doi.org/10.5194/gmd-12-1139-2019)

## Spatial and temporal information
Arrays contain daily jet feature data that has been constrained to the North Atlantic region (0-60 &deg; W, 15-75 &deg; N) and to the winter period (December, January and February)

## Prior processing
- Original dataset: netcdf files of daily zonal wind data from Polar Amplification Model Intercomparison Project simulations forced by present-day and future sea ice concentrations
- 850 hPa wind speed data was extracted
- Constrained to North Atlantic region and winter period
- Wind speed data was filtered using a 10-day Lanczos filter with a 61 day window
- Jet feature data was extracted for each day in ensemble member winters and saved to numpy arrays


## Example code for loading jet variables from csv file

To generate a numpy array of jet variable arrays contained in the csv file:
```python
loaded_jet_variable_arrays = np.genfromtxt((path_to_file/filename.csv'), delimiter=',')
```

To combine arrays for all ensemble member winters, which allows plotting of daily jet feature distributions:
```python
jet_variable_array_all_winters = np.concatenate(loaded_jet_variable_arrays)
```

